@@ -123,7 +123,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -139,28 +139,28 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_cloudwatch
-import aws_cdk.aws_events
-import aws_cdk.aws_iam
-import aws_cdk.aws_kinesis
-import constructs
+import aws_cdk.aws_cloudwatch as _aws_cdk_aws_cloudwatch_ceddda9d
+import aws_cdk.aws_events as _aws_cdk_aws_events_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_kinesis as _aws_cdk_aws_kinesis_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class EventbridgeToKinesisStreams(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-eventbridge-kinesisstreams.EventbridgeToKinesisStreams",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+        event_rule_props: typing.Union[_aws_cdk_aws_events_ceddda9d.RuleProps, typing.Dict[builtins.str, typing.Any]],
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+        event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+        existing_stream_obj: typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream] = None,
         kinesis_stream_props: typing.Any = None,
     ) -> None:
         '''
@@ -177,19 +177,7 @@ class EventbridgeToKinesisStreams(
         :summary: Constructs a new instance of the EventbridgeToKinesisStreams class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-                kinesis_stream_props: typing.Any = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__719e99574903097d001c8ae01c96eb2157eb855f1e3d20372365554dab7c2443)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventbridgeToKinesisStreamsProps(
@@ -205,30 +193,30 @@ class EventbridgeToKinesisStreams(
 
     @builtins.property
     @jsii.member(jsii_name="eventsRole")
-    def events_role(self) -> aws_cdk.aws_iam.Role:
-        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "eventsRole"))
+    def events_role(self) -> _aws_cdk_aws_iam_ceddda9d.Role:
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Role, jsii.get(self, "eventsRole"))
 
     @builtins.property
     @jsii.member(jsii_name="eventsRule")
-    def events_rule(self) -> aws_cdk.aws_events.Rule:
-        return typing.cast(aws_cdk.aws_events.Rule, jsii.get(self, "eventsRule"))
+    def events_rule(self) -> _aws_cdk_aws_events_ceddda9d.Rule:
+        return typing.cast(_aws_cdk_aws_events_ceddda9d.Rule, jsii.get(self, "eventsRule"))
 
     @builtins.property
     @jsii.member(jsii_name="kinesisStream")
-    def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
-        return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
+    def kinesis_stream(self) -> _aws_cdk_aws_kinesis_ceddda9d.Stream:
+        return typing.cast(_aws_cdk_aws_kinesis_ceddda9d.Stream, jsii.get(self, "kinesisStream"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_cloudwatch_ceddda9d.Alarm]]:
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_cloudwatch_ceddda9d.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
     @builtins.property
     @jsii.member(jsii_name="eventBus")
-    def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
-        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
+    def event_bus(self) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus], jsii.get(self, "eventBus"))
 
 
 @jsii.data_type(
@@ -247,11 +235,11 @@ class EventbridgeToKinesisStreamsProps:
     def __init__(
         self,
         *,
-        event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+        event_rule_props: typing.Union[_aws_cdk_aws_events_ceddda9d.RuleProps, typing.Dict[builtins.str, typing.Any]],
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+        event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+        existing_stream_obj: typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream] = None,
         kinesis_stream_props: typing.Any = None,
     ) -> None:
         '''
@@ -265,28 +253,18 @@ class EventbridgeToKinesisStreamsProps:
         :summary: The properties for the EventbridgeToKinesisStreams Construct
         '''
         if isinstance(event_rule_props, dict):
-            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
+            event_rule_props = _aws_cdk_aws_events_ceddda9d.RuleProps(**event_rule_props)
         if isinstance(event_bus_props, dict):
-            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
+            event_bus_props = _aws_cdk_aws_events_ceddda9d.EventBusProps(**event_bus_props)
         if __debug__:
-            def stub(
-                *,
-                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-                kinesis_stream_props: typing.Any = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__876f8fae3e114c62d79eb38d286a96e5ab914b3fe558103d414a47be65004e1b)
             check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
             check_type(argname="argument event_bus_props", value=event_bus_props, expected_type=type_hints["event_bus_props"])
             check_type(argname="argument existing_event_bus_interface", value=existing_event_bus_interface, expected_type=type_hints["existing_event_bus_interface"])
             check_type(argname="argument existing_stream_obj", value=existing_stream_obj, expected_type=type_hints["existing_stream_obj"])
             check_type(argname="argument kinesis_stream_props", value=kinesis_stream_props, expected_type=type_hints["kinesis_stream_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "event_rule_props": event_rule_props,
         }
         if create_cloud_watch_alarms is not None:
@@ -301,14 +279,14 @@ class EventbridgeToKinesisStreamsProps:
             self._values["kinesis_stream_props"] = kinesis_stream_props
 
     @builtins.property
-    def event_rule_props(self) -> aws_cdk.aws_events.RuleProps:
+    def event_rule_props(self) -> _aws_cdk_aws_events_ceddda9d.RuleProps:
         '''User provided eventRuleProps to override the defaults.
 
         :default: - None
         '''
         result = self._values.get("event_rule_props")
         assert result is not None, "Required property 'event_rule_props' is missing"
-        return typing.cast(aws_cdk.aws_events.RuleProps, result)
+        return typing.cast(_aws_cdk_aws_events_ceddda9d.RuleProps, result)
 
     @builtins.property
     def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
@@ -320,33 +298,37 @@ class EventbridgeToKinesisStreamsProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def event_bus_props(self) -> typing.Optional[aws_cdk.aws_events.EventBusProps]:
+    def event_bus_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.EventBusProps]:
         '''A new custom EventBus is created with provided props.
 
         :default: - None
         '''
         result = self._values.get("event_bus_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_events.EventBusProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.EventBusProps], result)
 
     @builtins.property
     def existing_event_bus_interface(
         self,
-    ) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
+    ) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus]:
         '''Existing instance of a custom EventBus.
 
         :default: - None
         '''
         result = self._values.get("existing_event_bus_interface")
-        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus], result)
 
     @builtins.property
-    def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
+    def existing_stream_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream]:
         '''Existing instance of Kinesis Stream object, providing both this and KinesisStreamProps will cause an error.
 
         :default: - Default props are used
         '''
         result = self._values.get("existing_stream_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.Stream], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream], result)
 
     @builtins.property
     def kinesis_stream_props(self) -> typing.Any:
@@ -375,3 +357,29 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__719e99574903097d001c8ae01c96eb2157eb855f1e3d20372365554dab7c2443(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    event_rule_props: typing.Union[_aws_cdk_aws_events_ceddda9d.RuleProps, typing.Dict[builtins.str, typing.Any]],
+    create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+    event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+    existing_stream_obj: typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream] = None,
+    kinesis_stream_props: typing.Any = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__876f8fae3e114c62d79eb38d286a96e5ab914b3fe558103d414a47be65004e1b(
+    *,
+    event_rule_props: typing.Union[_aws_cdk_aws_events_ceddda9d.RuleProps, typing.Dict[builtins.str, typing.Any]],
+    create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+    event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+    existing_stream_obj: typing.Optional[_aws_cdk_aws_kinesis_ceddda9d.Stream] = None,
+    kinesis_stream_props: typing.Any = None,
+) -> None:
+    """Type checking stubs"""
+    pass
